debugapi

package
v1.0.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 1, 2026 License: AGPL-3.0 Imports: 4 Imported by: 0

Documentation

Overview

Package debugapi provides primitives to interact with the openapi HTTP API.

Code generated by github.com/oapi-codegen/oapi-codegen/v2 version v2.7.0 DO NOT EDIT.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DebugErrorEvent

type DebugErrorEvent struct {
	Message string              `json:"message"`
	Type    DebugErrorEventType `json:"type"`
}

DebugErrorEvent defines model for DebugErrorEvent.

type DebugErrorEventType

type DebugErrorEventType string

DebugErrorEventType defines model for DebugErrorEvent.Type.

const (
	Error DebugErrorEventType = "error"
)

Defines values for DebugErrorEventType.

func (DebugErrorEventType) Valid

func (e DebugErrorEventType) Valid() bool

Valid indicates whether the value is a known member of the DebugErrorEventType enum.

type DebugEvent

type DebugEvent struct {
	// contains filtered or unexported fields
}

DebugEvent defines model for DebugEvent.

func (DebugEvent) AsDebugErrorEvent

func (t DebugEvent) AsDebugErrorEvent() (DebugErrorEvent, error)

AsDebugErrorEvent returns the union data inside the DebugEvent as a DebugErrorEvent

func (DebugEvent) AsDebugMessageEvent

func (t DebugEvent) AsDebugMessageEvent() (DebugMessageEvent, error)

AsDebugMessageEvent returns the union data inside the DebugEvent as a DebugMessageEvent

func (DebugEvent) AsDebugReadyEvent

func (t DebugEvent) AsDebugReadyEvent() (DebugReadyEvent, error)

AsDebugReadyEvent returns the union data inside the DebugEvent as a DebugReadyEvent

func (DebugEvent) Discriminator

func (t DebugEvent) Discriminator() (string, error)

func (*DebugEvent) FromDebugErrorEvent

func (t *DebugEvent) FromDebugErrorEvent(v DebugErrorEvent) error

FromDebugErrorEvent overwrites any union data inside the DebugEvent as the provided DebugErrorEvent

func (*DebugEvent) FromDebugMessageEvent

func (t *DebugEvent) FromDebugMessageEvent(v DebugMessageEvent) error

FromDebugMessageEvent overwrites any union data inside the DebugEvent as the provided DebugMessageEvent

func (*DebugEvent) FromDebugReadyEvent

func (t *DebugEvent) FromDebugReadyEvent(v DebugReadyEvent) error

FromDebugReadyEvent overwrites any union data inside the DebugEvent as the provided DebugReadyEvent

func (DebugEvent) MarshalJSON

func (t DebugEvent) MarshalJSON() ([]byte, error)

func (*DebugEvent) MergeDebugErrorEvent

func (t *DebugEvent) MergeDebugErrorEvent(v DebugErrorEvent) error

MergeDebugErrorEvent performs a merge with any union data inside the DebugEvent, using the provided DebugErrorEvent

func (*DebugEvent) MergeDebugMessageEvent

func (t *DebugEvent) MergeDebugMessageEvent(v DebugMessageEvent) error

MergeDebugMessageEvent performs a merge with any union data inside the DebugEvent, using the provided DebugMessageEvent

func (*DebugEvent) MergeDebugReadyEvent

func (t *DebugEvent) MergeDebugReadyEvent(v DebugReadyEvent) error

MergeDebugReadyEvent performs a merge with any union data inside the DebugEvent, using the provided DebugReadyEvent

func (*DebugEvent) UnmarshalJSON

func (t *DebugEvent) UnmarshalJSON(b []byte) error

func (DebugEvent) ValueByDiscriminator

func (t DebugEvent) ValueByDiscriminator() (interface{}, error)

type DebugExternalState

type DebugExternalState struct {
	// Gpio Pin number to value map (e.g. {"4": 1, "5": 0})
	Gpio *map[string]int `json:"gpio,omitempty"`

	// Serial Serial input buffer (consumed in order by ReadLine calls)
	Serial *[]string `json:"serial,omitempty"`
}

DebugExternalState Pre-populated hardware I/O values for the debug binary

type DebugMessageEvent

type DebugMessageEvent struct {
	Text string                `json:"text"`
	Type DebugMessageEventType `json:"type"`
}

DebugMessageEvent defines model for DebugMessageEvent.

type DebugMessageEventType

type DebugMessageEventType string

DebugMessageEventType defines model for DebugMessageEvent.Type.

const (
	Message DebugMessageEventType = "message"
)

Defines values for DebugMessageEventType.

func (DebugMessageEventType) Valid

func (e DebugMessageEventType) Valid() bool

Valid indicates whether the value is a known member of the DebugMessageEventType enum.

type DebugReadyEvent

type DebugReadyEvent struct {
	// SessionId Session ID for subsequent requests
	SessionId string              `json:"sessionId"`
	Type      DebugReadyEventType `json:"type"`
}

DebugReadyEvent defines model for DebugReadyEvent.

type DebugReadyEventType

type DebugReadyEventType string

DebugReadyEventType defines model for DebugReadyEvent.Type.

const (
	Ready DebugReadyEventType = "ready"
)

Defines values for DebugReadyEventType.

func (DebugReadyEventType) Valid

func (e DebugReadyEventType) Valid() bool

Valid indicates whether the value is a known member of the DebugReadyEventType enum.

type DebugRequest

type DebugRequest struct {
	// Workflow Workflow represents the deployment format of a project, passed to agents.
	Workflow externalRef0.Workflow `json:"workflow"`
}

DebugRequest defines model for DebugRequest.

type DebugStepRequest

type DebugStepRequest struct {
	// Context Workflow variable values (the Context struct in the generated C++)
	Context map[string]interface{} `json:"context"`

	// ExternalState Pre-populated hardware I/O values for the debug binary
	ExternalState DebugExternalState `json:"externalState"`

	// NodeId Node to execute. If provided, sets the cursor first (debug from here). If omitted, executes the current cursor node.
	NodeId *string `json:"nodeId,omitempty"`
}

DebugStepRequest defines model for DebugStepRequest.

type DebugStepResult

type DebugStepResult struct {
	// Context Updated workflow variable values after execution
	Context      map[string]interface{} `json:"context"`
	ExecutedNode string                 `json:"executedNode"`

	// NextNode Next node to execute. Empty string if execution reached idle.
	NextNode string `json:"nextNode"`
}

DebugStepResult defines model for DebugStepResult.

Jump to